@@ -1,4 +1,4 @@
-from django.conf.urls import url, patterns
+from django.conf.urls import url
 from django.contrib import admin
 from django.http import HttpResponseRedirect
 try:
@@ -20,12 +20,20 @@ class SingletonModelAdmin(admin.ModelAdmin):
 
     def get_urls(self):
         urls = super(SingletonModelAdmin, self).get_urls()
+
+        # _meta.model_name only exists on Django>=1.6 -
+        # on earlier versions, use module_name.lower()
+        try:
+            model_name = self.model._meta.model_name
+        except AttributeError:
+            model_name = self.model._meta.module_name.lower()
+
         self.model._meta.verbose_name_plural = self.model._meta.verbose_name
         url_name_prefix = '%(app_name)s_%(model_name)s' % {
             'app_name': self.model._meta.app_label,
-            'model_name': self.model._meta.model_name,
+            'model_name': model_name,
         }
-        custom_urls = patterns('',
+        custom_urls = [
             url(r'^history/$',
                 self.admin_site.admin_view(self.history_view),
                 {'object_id': '1'},
@@ -34,7 +42,7 @@ class SingletonModelAdmin(admin.ModelAdmin):
                 self.admin_site.admin_view(self.change_view),
                 {'object_id': '1'},
                 name='%s_change' % url_name_prefix),
-        )
+        ]
         # By inserting the custom URLs first, we overwrite the standard URLs.
         return custom_urls + urls
 
