@@ -1,12 +1,16 @@
 from django.conf import settings
-from django.core.cache import get_cache
 from django.db import models
 
+try:
+    from django.core.cache import caches
+    get_cache = lambda cache_name: caches[cache_name]
+except ImportError:
+    from django.core.cache import get_cache
+
 from solo import settings as solo_settings
 
 
 class SingletonModel(models.Model):
-
     class Meta:
         abstract = True
 
